==> zio-aws-memorydb_3-5.17.121.3-sources.jar: zio/aws/memorydb/model/UpdateUserResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class UpdateUserResponse(
    user: Option[zio.aws.memorydb.model.User] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.UpdateUserResponse = {
    import UpdateUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.UpdateUserResponse
      .builder()
      .optionallyWith(user.map(value => value.buildAwsValue()))(_.user)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.UpdateUserResponse.ReadOnly =
    zio.aws.memorydb.model.UpdateUserResponse.wrap(buildAwsValue())
}
object UpdateUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.UpdateUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.UpdateUserResponse =
      zio.aws.memorydb.model
        .UpdateUserResponse(user.map(value => value.asEditable))
    def user: Option[zio.aws.memorydb.model.User.ReadOnly]
    def getUser: ZIO[Any, AwsError, zio.aws.memorydb.model.User.ReadOnly] =
      AwsError.unwrapOptionField("user", user)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.UpdateUserResponse
  ) extends zio.aws.memorydb.model.UpdateUserResponse.ReadOnly {
    override val user: Option[zio.aws.memorydb.model.User.ReadOnly] = scala
      .Option(impl.user())
      .map(value => zio.aws.memorydb.model.User.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.UpdateUserResponse
  ): zio.aws.memorydb.model.UpdateUserResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-memorydb_3-5.17.234.1-sources.jar: zio/aws/memorydb/model/UpdateUserResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class UpdateUserResponse(
    user: Optional[zio.aws.memorydb.model.User] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.UpdateUserResponse = {
    import UpdateUserResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.UpdateUserResponse
      .builder()
      .optionallyWith(user.map(value => value.buildAwsValue()))(_.user)
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.UpdateUserResponse.ReadOnly =
    zio.aws.memorydb.model.UpdateUserResponse.wrap(buildAwsValue())
}
object UpdateUserResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.UpdateUserResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.UpdateUserResponse =
      zio.aws.memorydb.model
        .UpdateUserResponse(user.map(value => value.asEditable))
    def user: Optional[zio.aws.memorydb.model.User.ReadOnly]
    def getUser: ZIO[Any, AwsError, zio.aws.memorydb.model.User.ReadOnly] =
      AwsError.unwrapOptionField("user", user)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.UpdateUserResponse
  ) extends zio.aws.memorydb.model.UpdateUserResponse.ReadOnly {
    override val user: Optional[zio.aws.memorydb.model.User.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.user())
        .map(value => zio.aws.memorydb.model.User.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.UpdateUserResponse
  ): zio.aws.memorydb.model.UpdateUserResponse.ReadOnly = new Wrapper(impl)
}
